## Core API

The primary way to interact with the Ravelry API.
::: pyravelry.client

## Configuration

Manage your API keys and environment variables.
::: pyravelry.settings

---

## Technical Reference

Detailed breakdowns of the internal logic.

### Endpoints

::: pyravelry.endpoints

### Data Models

::: pyravelry.models
